import {FC, useCallback, useEffect, useState} from "react";
import {Image, View} from "@tarojs/components";
import {brandApi, BrandRecord} from "@/api";
import styles from './list.module.scss'
import Taro, {useReachBottom} from "@tarojs/taro";
import Empty from "@/components/empty/empty";

const BrandList: FC = () => {
  const [page, setPage] = useState(1)
  const [brands, setBrands] = useState<BrandRecord[]>([])
  const [total, setTotal] = useState(0)
  const [text, setText] = useState('')

  useEffect(() => {
    Taro.showLoading({
      title: '加载中',
      mask: true
    })
    setTimeout(function () {
      Taro.hideLoading()
    }, 650)
    getData()
  }, [page])

  const getData = useCallback(async () => {
    try {
      setText('加载中..')
      const res = await brandApi.list(page, 10)
      if(page === 1){
        if(res.list.length < 10) {
          setText('没有更多了~')
        }else{
          setText('上拉加载更多~')
        }
      }
      setTotal(res.total)
      setBrands([
        ...brands,
        ...res.list
      ])
    } catch (e) {
    }
  }, [page])


  function jumpInfo(id: number) {
    Taro.navigateTo({url: `/pages/preview/brand/info/info?id=${id}`})
  }

  useReachBottom(useCallback(() => {
    if (brands?.length < total) {
      setPage(page + 1)
    }else{
      setText('没有更多了~')
    }
  }, [total, brands]))


  return (
    <View className='p-2' style={{display:text?'block':'none'}}>
      {
        brands.length ?
          <>
          { brands.map((d) => <View onClick={() => jumpInfo(d.id)} className={styles.box} key={d.id}>
              <Image src={d.logo} mode='aspectFill' className={styles.image}/>
              <View className={styles.rightBox}>
                <View className='font-weight mb-2 font-28'>{d.name}</View>
                <View className={styles.desc}>{d.graphic_introduction}</View>
              </View>
            </View>)
          }
          <View style={{width:'750rpx',textAlign:'center',color:'#ccc'}} className="font-28 mt-3">{text}</View>
          </>: <Empty name='空空如也'/>
      }
    </View>
  )
}

export default BrandList
